#[non_exhaustive]pub enum Algorithm {
SHA1,
SHA256,
SHA512,
Steam,
}Expand description
Algorithm enum holds the three standards algorithms for TOTP as per the reference implementation
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
SHA1
HMAC-SHA1 is the default algorithm of most TOTP implementations. Some will outright silently ignore the algorithm parameter to force using SHA1, leading to confusion.
SHA256
HMAC-SHA256. Supported in theory according to yubico. Ignored in practice by most.
SHA512
HMAC-SHA512. Supported in theory according to yubico. Ignored in practice by most.
Steam
Available on crate feature
steam only.Steam TOTP token algorithm.
Implementations